@@ -24,10 +24,7 @@
 #include <string.h>
 
 #include <libgnome/gnome-config.h>
-#include <libgnomeui/gnome-client.h>
-#include <libgnomeui/gnome-app.h>
-#include <libgnomeui/gnome-ui-init.h>
-#include <libgnomeui/gnome-window-icon.h>
+#include <libgnomeui/libgnomeui.h>
 #include <libgnomevfs/gnome-vfs-init.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
@@ -36,7 +33,7 @@
 #include "fr-process.h"
 #include "fr-stock.h"
 #include "gconf-utils.h"
-#include "window.h"
+#include "fr-window.h"
 #include "typedefs.h"
 #include "preferences.h"
 #include "file-data.h"
@@ -50,11 +47,11 @@ static void     init_session        (char **argv);
 static gboolean session_is_restored (void);
 static gboolean load_session        (void);
 
-GList        *window_list = NULL;
-GList        *viewer_list = NULL;
-GList        *command_list = NULL;
-gint          force_directory_creation;
-GHashTable   *programs_cache = NULL;
+GList        *WindowList = NULL;
+GList        *ViewerList = NULL;
+GList        *CommandList = NULL;
+gint          ForceDirectoryCreation;
+GHashTable   *ProgramsCache = NULL;
 
 static gchar **remaining_args;
 
@@ -76,6 +73,7 @@ FRFileTypeDescription file_type_desc[] = {
 	{ FR_FILE_TYPE_DEB,          ".deb",     "application/x-deb", NULL },
 	{ FR_FILE_TYPE_ISO,          ".iso",     "application/x-cd-image", NULL },
 	{ FR_FILE_TYPE_EAR,          ".ear",     "application/x-ear", N_("Ear (.ear)") },
+	{ FR_FILE_TYPE_EXE,          ".exe",     "application/x-ms-dos-executable", N_("Self-extracting zip (.exe)") },
 	{ FR_FILE_TYPE_GZIP,         ".gz",      "application/x-gzip", NULL},
 	{ FR_FILE_TYPE_JAR,          ".jar",     "application/x-jar", N_("Jar (.jar)")},
 	{ FR_FILE_TYPE_LHA,          ".lzh",     "application/x-lha", N_("Lha (.lzh)") },
@@ -118,6 +116,7 @@ FRCommandDescription command_desc[] = {
 	{ "isoinfo",    TRUE,  FALSE, TRUE,  FR_FILE_TYPE_ISO },
 	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_EAR },
 	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_JAR },
+	{ "zip",        TRUE,  FALSE,  TRUE,  FR_FILE_TYPE_EXE },
 	{ "lha",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_LHA },
 	{ "lzop",       TRUE,  TRUE,  FALSE, FR_FILE_TYPE_LZOP },
 	{ "rpm2cpio",   TRUE,  FALSE, TRUE,  FR_FILE_TYPE_RPM },
@@ -163,7 +162,7 @@ static const GOptionEntry options[] = {
 	  N_("Default folder to use for the '--add' and '--extract' commands"),
 	  N_("FOLDER") },
 
-	{ "force", '\0', 0, G_OPTION_ARG_NONE, &force_directory_creation,
+	{ "force", '\0', 0, G_OPTION_ARG_NONE, &ForceDirectoryCreation,
 	  N_("Create destination folder without asking confirmation"),
 	  NULL },
 
@@ -211,24 +210,28 @@ main (int argc, char **argv)
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
 	program = gnome_program_init ("file-roller", VERSION,
-				      LIBGNOMEUI_MODULE, argc, argv,
+				      LIBGNOMEUI_MODULE, 
+				      argc, argv,
 				      GNOME_PARAM_GOPTION_CONTEXT, context,
 				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Archive Manager"),
 				      GNOME_PARAM_APP_PREFIX, FR_PREFIX,
-                                      GNOME_PARAM_APP_SYSCONFDIR, FR_SYSCONFDIR,
-                                      GNOME_PARAM_APP_DATADIR, FR_DATADIR,
-                                      GNOME_PARAM_APP_LIBDIR, FR_LIBDIR,
+				      GNOME_PARAM_APP_SYSCONFDIR, FR_SYSCONFDIR,
+				      GNOME_PARAM_APP_DATADIR, FR_DATADIR,
+				      GNOME_PARAM_APP_LIBDIR, FR_LIBDIR,
 				      NULL);
 
 	g_set_application_name (_("File Roller"));
 	gtk_window_set_default_icon_name ("file-roller");
 
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-                                           PKG_DATA_DIR G_DIR_SEPARATOR_S "icons");
+					   PKG_DATA_DIR G_DIR_SEPARATOR_S "icons");
 
+/*
 	if (! gnome_vfs_init ())
-                g_error ("Cannot initialize the Virtual File System.");
+		g_error ("Cannot initialize the Virtual File System.");
+*/
 
+	gnome_authentication_manager_init ();
 	glade_init ();
 	fr_stock_init ();
 	init_session (argv);
@@ -248,7 +251,7 @@ initialize_data (void)
 	eel_gconf_monitor_add ("/apps/file-roller");
 	eel_gconf_monitor_add (PREF_NAUTILUS_CLICK_POLICY);
 
-	programs_cache = g_hash_table_new_full (g_str_hash,
+	ProgramsCache = g_hash_table_new_full (g_str_hash,
 						g_str_equal,
 						g_free,
 						NULL);
@@ -280,7 +283,7 @@ viewer_done (ViewerData *vdata)
 	if (vdata->process != NULL)
 		g_object_unref (vdata->process);
 
-	viewer_list = g_list_remove (viewer_list, vdata);
+	ViewerList = g_list_remove (ViewerList, vdata);
 	g_free (vdata);
 }
 
@@ -310,7 +313,7 @@ command_done (CommandData *cdata)
 	if (cdata->process != NULL)
 		g_object_unref (cdata->process);
 
-	command_list = g_list_remove (command_list, cdata);
+	CommandList = g_list_remove (CommandList, cdata);
 	g_free (cdata);
 }
 
@@ -318,101 +321,82 @@ command_done (CommandData *cdata)
 static void
 release_data ()
 {
-	g_hash_table_destroy (programs_cache);
+	g_hash_table_destroy (ProgramsCache);
 	file_data_release_data ();
 
 	eel_global_client_free ();
 
-	while (viewer_list != NULL) {
-		ViewerData *vdata = viewer_list->data;
+	while (ViewerList != NULL) {
+		ViewerData *vdata = ViewerList->data;
 		viewer_done (vdata);
 	}
 
-	while (command_list != NULL) {
-		CommandData *cdata = command_list->data;
+	while (CommandList != NULL) {
+		CommandData *cdata = CommandList->data;
 		command_done (cdata);
 	}
 }
 
 /* Create the windows. */
 
-static char *
-get_path_from_url (char *url)
-{
-	GnomeVFSURI *uri;
-	char        *path;
-	char        *escaped;
-
-	if (url == NULL)
-		return NULL;
-
-	uri = gnome_vfs_uri_new (url);
-	escaped = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-	gnome_vfs_uri_unref (uri);
-	path = gnome_vfs_unescape_string (escaped, NULL);
-	g_free (escaped);
-
-	return path;
-}
-
 
 static void
 migrate_dir_from_to (const char *from_dir,
-                     const char *to_dir)
+		     const char *to_dir)
 {
-        char *from_path;
-        char *to_path;
+	char *from_path;
+	char *to_path;
 
-        from_path = get_home_relative_dir (from_dir);
-        to_path = get_home_relative_dir (to_dir);
+	from_path = get_home_relative_dir (from_dir);
+	to_path = get_home_relative_dir (to_dir);
 
-        if (path_is_dir (from_path) && ! path_is_dir (to_path)) {
-                char *line;
-                char *e1;
-                char *e2;
+	if (path_is_dir (from_path) && ! path_is_dir (to_path)) {
+		char *line;
+		char *e1;
+		char *e2;
 
-                e1 = shell_escape (from_path);
-                e2 = shell_escape (to_path);
-                line = g_strdup_printf ("mv -f %s %s", e1, e2);
-                g_free (e1);
-                g_free (e2);
+		e1 = shell_escape (from_path);
+		e2 = shell_escape (to_path);
+		line = g_strdup_printf ("mv -f %s %s", e1, e2);
+		g_free (e1);
+		g_free (e2);
 
-                g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
-                g_free (line);
-        }
+		g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
+		g_free (line);
+	}
 
-        g_free (from_path);
-        g_free (to_path);
+	g_free (from_path);
+	g_free (to_path);
 }
 
 
 static void
 migrate_file_from_to (const char *from_file,
-                      const char *to_file)
+		      const char *to_file)
 {
-        char *from_path;
-        char *to_path;
+	char *from_path;
+	char *to_path;
 
-        from_path = get_home_relative_dir (from_file);
-        to_path = get_home_relative_dir (to_file);
+	from_path = get_home_relative_dir (from_file);
+	to_path = get_home_relative_dir (to_file);
 
-        if (path_is_file (from_path) && ! path_is_file (to_path)) {
-                char *line;
-                char *e1;
-                char *e2;
+	if (path_is_file (from_path) && ! path_is_file (to_path)) {
+		char *line;
+		char *e1;
+		char *e2;
 
-                e1 = shell_escape (from_path);
-                e2 = shell_escape (to_path);
-                line = g_strdup_printf ("mv -f %s %s", e1, e2);
-                g_free (e1);
-                g_free (e2);
+		e1 = shell_escape (from_path);
+		e2 = shell_escape (to_path);
+		line = g_strdup_printf ("mv -f %s %s", e1, e2);
+		g_free (e1);
+		g_free (e2);
 
-                g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
-                g_free (line);
-        }
+		g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
+		g_free (line);
+	}
 
-        g_free (from_path);
-        g_free (to_path);
+	g_free (from_path);
+	g_free (to_path);
 }
 
 
@@ -421,7 +405,7 @@ migrate_to_new_directories (void)
 {
 	migrate_dir_from_to  (OLD_RC_OPTIONS_DIR, RC_OPTIONS_DIR);
 	migrate_file_from_to (OLD_RC_BOOKMARKS_FILE, RC_BOOKMARKS_FILE);
-        migrate_file_from_to (OLD_RC_RECENT_FILE, RC_RECENT_FILE);
+	migrate_file_from_to (OLD_RC_RECENT_FILE, RC_RECENT_FILE);
 
 	eel_gconf_set_boolean (PREF_MIGRATE_DIRECTORIES, FALSE);
 }
@@ -464,13 +448,35 @@ compute_supported_archive_types (void)
 }
 
 
+static char *
+get_uri_from_command_line (const char *path)
+{
+	char *current_dir;
+	char *full_path;
+	char *uri;
+
+	if (uri_has_scheme (path) || g_path_is_absolute (path))
+		return g_strdup (path);
+
+	current_dir = g_get_current_dir ();
+	full_path = g_build_filename (current_dir,
+				      path,
+				      NULL);
+	uri = get_uri_from_path (full_path);
+
+	g_free (current_dir);
+	g_free (full_path);
+
+	return uri;
+}
+
+
 static void
 prepare_app (void)
 {
 	char *path;
-	char *default_dir;
 	char *extract_to_path = NULL;
-        char *add_to_path = NULL;
+	char *add_to_path = NULL;
 
 	/* create the config dir if necessary. */
 
@@ -484,9 +490,9 @@ prepare_app (void)
 	g_free (path);
 
 	if (eel_gconf_get_boolean (PREF_MIGRATE_DIRECTORIES, TRUE))
-                migrate_to_new_directories ();
+		migrate_to_new_directories ();
 
-	compute_supported_archive_types();
+	compute_supported_archive_types ();
 
 	if (session_is_restored ()) {
 		load_session ();
@@ -496,108 +502,95 @@ prepare_app (void)
 	/**/
 
 	if (remaining_args == NULL) { /* No archive specified. */
-		FRWindow *window;
-		window = window_new ();
-		gtk_widget_show (window->app);
+		gtk_widget_show (fr_window_new ());
 		return;
 	}
 
-	default_dir = get_path_from_url (default_url);
+	if (extract_to != NULL)
+		extract_to_path = get_uri_from_command_line (extract_to);
 
-	if (extract_to != NULL) {
-		if (g_path_is_absolute (extract_to))
-			extract_to_path = get_path_from_url (extract_to);
-		else {
-			char *current_dir = g_get_current_dir ();
-			char *full_path;
-
-			full_path = g_build_filename (current_dir,
-						      extract_to,
-						      NULL);
-			extract_to_path = get_path_from_url (full_path);
-
-			g_free (current_dir);
-			g_free (full_path);
-		}
-	}
-
-        add_to_path = get_path_from_url (add_to);
+	if (add_to != NULL)
+		add_to_path = get_uri_from_command_line (add_to);
 
 	if ((add_to != NULL) || (add == 1)) { /* Add files to an archive */
-		FRWindow    *window;
+		GtkWidget   *window;
 		GList       *file_list = NULL;
 		const char  *filename;
 		int          i = 0;
 
-		window = window_new ();
-		if (default_dir != NULL)
-			window_set_default_dir (window, default_dir, TRUE);
+		window = fr_window_new ();
+		if (default_url != NULL)
+			fr_window_set_default_dir (FR_WINDOW (window), default_url, TRUE);
 
-		while ((filename = remaining_args[i++]) != NULL) {
-			char *path;
-
-			if (! g_path_is_absolute (filename)) {
-				char *current_dir;
-				current_dir = g_get_current_dir ();
-				path = g_strconcat (current_dir,
-						    "/",
-						    filename,
-						    NULL);
-				g_free (current_dir);
-			} else
-				path = g_strdup (filename);
-			file_list = g_list_prepend (file_list, path);
-		}
+		while ((filename = remaining_args[i++]) != NULL)
+			file_list = g_list_prepend (file_list, get_uri_from_command_line (filename));
 		file_list = g_list_reverse (file_list);
 
-		window_archive__open_add (window, add_to_path, file_list);
-		window_archive__quit (window);
-		window_batch_mode_start (window);
-
-	} else if ((extract_to != NULL)
-		   || (extract == 1)
-		   || (extract_here == 1)) { /* Extract all archives. */
-		FRWindow   *window;
+		fr_window_new_batch (FR_WINDOW (window));
+		fr_window_set_batch__add (FR_WINDOW (window), add_to_path, file_list);
+		fr_window_append_batch_action (FR_WINDOW (window),
+					       FR_BATCH_ACTION_QUIT,
+					       NULL,
+					       NULL);
+		fr_window_start_batch (FR_WINDOW (window));
+	}
+	else if ((extract_to != NULL)
+		  || (extract == 1)
+		  || (extract_here == 1)) { /* Extract all archives. */
+		GtkWidget  *window;
 		const char *archive;
 		int         i = 0;
 
-		window = window_new ();
-		if (default_dir != NULL)
-			window_set_default_dir (window, default_dir, TRUE);
+		window = fr_window_new ();
+		if (default_url != NULL)
+			fr_window_set_default_dir (FR_WINDOW (window), default_url, TRUE);
 
+		fr_window_new_batch (FR_WINDOW (window));
 		while ((archive = remaining_args[i++]) != NULL) {
 			if (extract_here == 1)
-				window_archive__open_extract_here (window,
+				fr_window_set_batch__extract_here (FR_WINDOW (window),
 								   archive,
 								   extract_to_path);
 			else
-				window_archive__open_extract (window,
+				fr_window_set_batch__extract (FR_WINDOW (window),
 							      archive,
 							      extract_to_path);
 		}
-		window_archive__quit (window);
-		window_batch_mode_start (window);
+		fr_window_append_batch_action (FR_WINDOW (window),
+					       FR_BATCH_ACTION_QUIT,
+					       NULL,
+					       NULL);
 
-	} else { /* Open each archive in a window */
+		if (eel_gconf_get_boolean (PREF_EXTRACT_VIEW_FOLDER, FALSE))
+			/* open the destination folder only if we are 
+			 * extracting a single archive. */					       
+			fr_window_view_folder_after_extract (FR_WINDOW (window), (i - 1 == 1));
+					       
+		fr_window_start_batch (FR_WINDOW (window));
+	}
+	else { /* Open each archive in a window */
 		const char *archive;
 
 		int i = 0;
 		while ((archive = remaining_args[i++]) != NULL) {
-			FRWindow *window;
-
-			window = window_new ();
-			gtk_widget_show (window->app);
-			window_archive_open (window, archive, GTK_WINDOW (window->app));
+			GtkWidget *window;
+			char      *uri;
+			
+			window = fr_window_new ();
+			gtk_widget_show (window);
+			
+			uri = gnome_vfs_make_uri_from_shell_arg (archive);
+			fr_window_archive_open (FR_WINDOW (window), uri, GTK_WINDOW (window));
+			g_free (uri);
 		}
 	}
 
-	g_free (default_dir);
 	g_free (add_to_path);
-        g_free (extract_to_path);
+	g_free (extract_to_path);
 }
 
 
- /* SM support */
+/* SM support */
 
 
 /* The master client we use for SM */
@@ -617,17 +610,16 @@ save_session (GnomeClient *client)
 	prefix = gnome_client_get_config_prefix (client);
 	gnome_config_push_prefix (prefix);
 
-	for (scan = window_list; scan; scan = scan->next) {
-		FRWindow *window = scan->data;
+	for (scan = WindowList; scan; scan = scan->next) {
+		FrWindow *window = scan->data;
 		char     *key;
 
 		key = g_strdup_printf ("Session/archive%d", i);
 
-		if ((window->archive == NULL)
-		    || (window->archive->filename == NULL))
+		if ((window->archive == NULL) || (window->archive->uri == NULL))
 			gnome_config_set_string (key, "");
 		else
-			gnome_config_set_string (key, window->archive->filename);
+			gnome_config_set_string (key, window->archive->uri);
 		g_free (key);
 
 		i++;
@@ -730,18 +722,18 @@ load_session (void)
 
 	n = gnome_config_get_int ("Session/archives");
 	for (i = 0; i < n; i++) {
-		FRWindow *window;
-		char     *key;
-		char     *filename;
+		GtkWidget *window;
+		char      *key;
+		char      *filename;
 
 		key = g_strdup_printf ("Session/archive%d", i);
 		filename = gnome_config_get_string (key);
 		g_free (key);
 
-		window = window_new ();
-		gtk_widget_show (window->app);
+		window = fr_window_new ();
+		gtk_widget_show (window);
 		if (strlen (filename) != 0)
-			window_archive_open (window, filename, GTK_WINDOW (window->app));
+			fr_window_archive_open (FR_WINDOW (window), filename, GTK_WINDOW (window));
 
 		g_free (filename);
 	}
