@@ -26,7 +26,7 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkenums.h>
 #include "typedefs.h"
-#include "window.h"
+#include "fr-window.h"
 
 #define PREF_LIST_SORT_METHOD      "/apps/file-roller/listing/sort_method"
 #define PREF_LIST_SORT_TYPE        "/apps/file-roller/listing/sort_type"
@@ -37,6 +37,8 @@
 #define PREF_LIST_SHOW_PATH        "/apps/file-roller/listing/show_path"
 #define PREF_LIST_USE_MIME_ICONS   "/apps/file-roller/listing/use_mime_icons"
 
+#define PREF_UI_WINDOW_WIDTH       "/apps/file-roller/ui/window_width"
+#define PREF_UI_WINDOW_HEIGHT      "/apps/file-roller/ui/window_height"
 #define PREF_UI_HISTORY_LEN        "/apps/file-roller/ui/history_len"
 #define PREF_UI_TOOLBAR            "/apps/file-roller/ui/view_toolbar"
 #define PREF_UI_STATUSBAR          "/apps/file-roller/ui/view_statusbar"
@@ -56,27 +58,19 @@
 #define PREF_DESKTOP_MENUS_HAVE_TEAROFF "/desktop/gnome/interface/menus_have_tearoff"
 #define PREF_DESKTOP_MENUBAR_DETACHABLE "/desktop/gnome/interface/menubar_detachable"
 #define PREF_DESKTOP_TOOLBAR_DETACHABLE "/desktop/gnome/interface/toolbar_detachable"
+#define PREF_NAUTILUS_CLICK_POLICY "/apps/nautilus/preferences/click_policy"
 
-WindowSortMethod    preferences_get_sort_method ();
-
-void                preferences_set_sort_method (WindowSortMethod i_value);
-
-GtkSortType         preferences_get_sort_type ();
-
-void                preferences_set_sort_type (GtkSortType i_value);
-
-WindowListMode      preferences_get_list_mode ();
-
-void                preferences_set_list_mode (WindowListMode i_value);
-
-FRCompression       preferences_get_compression_level ();
-
-void                preferences_set_compression_level (FRCompression i_value);
-
-void                pref_util_save_window_geometry (GtkWindow  *window,
-						    const char *dialog);
-
-void                pref_util_restore_window_geometry (GtkWindow  *window,
-						       const char *dialog);
+FRWindowSortMethod  preferences_get_sort_method       (void);
+void                preferences_set_sort_method       (FRWindowSortMethod  i_value);
+GtkSortType         preferences_get_sort_type         (void);
+void                preferences_set_sort_type         (GtkSortType         i_value);
+FRWindowListMode    preferences_get_list_mode         (void);
+void                preferences_set_list_mode         (FRWindowListMode    i_value);
+FRCompression       preferences_get_compression_level (void);
+void                preferences_set_compression_level (FRCompression       i_value);
+void                pref_util_save_window_geometry    (GtkWindow          *window,
+						       const char         *dialog);
+void                pref_util_restore_window_geometry (GtkWindow          *window,
+						       const char         *dialog);
 
 #endif /* PREFERENCES_H */
